/* vim:fdm=marker ts=4 et ai
 * {{{
 *
 * (c) by Alexander Neumann <alexander@bumpern.de>
 * Copyright (C) 2007 by Stefan Siegl <stesie@brokenpipe.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * For more information on the GPL, please go to:
 * http://www.gnu.org/copyleft/gpl.html
 }}} */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/wdt.h>
#include <util/delay.h>
#include <stdlib.h>

#include "config.h"
#include "common.h"
#include "network.h"
#include "spi.h"
#include "enc28j60.h"
#include "timer.h"

#include "uip/uip.h"
#include "uip/uip_arp.h"

void 
librape_init(void)
{
    /* enable interrupts */
    sei();

    spi_init();
    timer_init();

    network_init();
}

void
librape_periodic(void)
{
    /* check for network controller interrupts */
    enc28j60_process_interrupts();

    /* check for timer interrupt */
    if (_TIFR_TIMER1 & _BV(OCF1A)) {
        static uint8_t c;
        c++;

#       if UIP_CONNS <= 255
        uint8_t i;
#       else
        uint16_t i;
#       endif

#       if UIP_TCP == 1
        /* periodically check connections */
        for (i = 0; i < UIP_CONNS; i++) {
            uip_periodic(i);

            /* if this generated a packet, send it now */
            if (uip_len > 0) {
                uip_arp_out();
                transmit_packet();
            }
        }
#       endif

#       if UIP_UDP == 1
        for (i = 0; i < UIP_UDP_CONNS; i++) {
            uip_udp_periodic(i);

            /* if this generated a packet, send it now */
            if (uip_len > 0) {
                uip_arp_out();
                transmit_packet();
            }
        }
#       endif

        if (c == 50) { /* every 10 secs */
            uip_arp_timer();
            c = 0;
        }

        /* clear flag */
        _TIFR_TIMER1 = _BV(OCF1A);
    }
}

