/* uip configuration */

#ifndef __UIP_CONF_H__
#define __UIP_CONF_H__

#include <inttypes.h>
#include <etherrape.h>
/* #include "../config.h" */
/* #include "../network.h" */

/* handle tcp connections */
void UIP_APPCALL(void);

/* handle udp connections */
void UIP_UDP_APPCALL(void);

/* configure global data buffer */
#define MAX_FRAME_LENGTH 640

#ifdef LIBRAPE_INTERNAL
/* uip tcp appstate */
typedef union uip_tcp_connection_state {
    unsigned char placeholder[UIP_APPDATA_TCP_LEN];
} uip_tcp_appstate_t;

/* uip udp appstate */
typedef union uip_udp_connection_state {
    unsigned char placeholder[UIP_APPDATA_UDP_LEN];
} uip_udp_appstate_t;
#endif

/**
 * 8 bit datatype
 *
 * This typedef defines the 8-bit type used throughout uIP.
 *
 * \hideinitializer
 */
typedef uint8_t u8_t;

/**
 * 16 bit datatype
 *
 * This typedef defines the 16-bit type used throughout uIP.
 *
 * \hideinitializer
 */
typedef uint16_t u16_t;

/**
 * Statistics datatype
 *
 * This typedef defines the dataype used for keeping statistics in
 * uIP.
 *
 * \hideinitializer
 */
typedef unsigned short uip_stats_t;

/**
 * Maximum number of TCP connections.
 *
 * \hideinitializer
 */
#define UIP_CONF_MAX_CONNECTIONS 10

/**
 * Maximum number of listening TCP ports.
 *
 * \hideinitializer
 */
#define UIP_CONF_MAX_LISTENPORTS 5

/**
 * uIP buffer size.
 *
 * \hideinitializer
 */
#define UIP_CONF_BUFFER_SIZE     MAX_FRAME_LENGTH

/**
 * CPU byte order.
 *
 * \hideinitializer
 */
#define UIP_CONF_BYTE_ORDER      UIP_LITTLE_ENDIAN

/**
 * Logging on or off
 *
 * \hideinitializer
 */
#ifdef DEBUG
#   define UIP_CONF_LOGGING         1
#else
#   define UIP_CONF_LOGGING         0
#endif

/** UDP support on or off */
#define UIP_CONF_UDP             1
#define UIP_CONF_UDP_CONNS            5

/**
 * UDP checksums on or off
 *
 * \hideinitializer
 */
#ifndef UIP_CONF_UDP_CHECKSUMS
#define UIP_CONF_UDP_CHECKSUMS   0
#endif

/**
 * uIP statistics on or off
 *
 * \hideinitializer
 */
#ifndef UIP_CONF_STATISTICS
#define UIP_CONF_STATISTICS      0
#endif

#define UIP_CONF_BROADCAST       1


#define UIP_CONF_IPV6            0
#define UIP_ARCH_ADD32           0
#define UIP_ARCH_CHKSUM          0

#endif /* __UIP_CONF_H__ */
